@@ -132,11 +132,11 @@ is a null operation. When undef als argument is provided, then the element is de
 element an ARRAY (ref) of MODS::Element::Xxx can be provided (where 'Xxx' is the corresponding MODS element). E.g.
 
  # Delete all abstracts
- $mods->abstract(undef);
+ $mods->set_abstract(undef);
 
  # Set all abstracts
- $mods->abstract(MODS::Element::Abstract->new(), MODS::Element::Abstract->new(), ...);
- $mods->abstract([ MODS::Element::Abstract->new(), MODS::Element::Abstract->new(), ... ]);
+ $mods->set_abstract(MODS::Element::Abstract->new(), MODS::Element::Abstract->new(), ...);
+ $mods->set_abstract([ MODS::Element::Abstract->new(), MODS::Element::Abstract->new(), ... ]);
 
 =head2 as_xml()
 
@@ -178,11 +178,15 @@ Parse and JSON string or JSON::Handle into a MODS::Record.
 
 =item * I needed a MODS module to parse and create MODS records for our institutional repository
 
+=item * This module is part of the LibreCat/Catmandu project http://librecat.org
+
 =item * This module is not created for speed
 
 =item * This module doesn't have any notion of ordering of MODS elements themselves (e.g. first 'titleInfo', then 'name').
 But each sub-element keeps its original order (e.g. each 'title' in 'titleInfo').
 
+=item * Heiko Jansen provides at GitHub a Moose-based MODS parser https://github.com/heikojansen/MODS--Record
+
 =back
 
 =head1 AUTHORS
@@ -196,7 +200,7 @@ But each sub-element keeps its original order (e.g. each 'title' in 'titleInfo')
 =cut
 
 use vars qw( $VERSION );
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -283,9 +287,6 @@ sub AUTOLOAD {
 
 		return $self->_setter($attrib,@args);
 	}
-	else {
-		die "no such method $meth";
-	}
 }
 
 sub escape {
